require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xcredssp',
  dscmeta_resource_friendly_name: 'xCredSSP',
  dscmeta_resource_name: 'MSFT_xCredSSP',
  dscmeta_module_name: 'xCredSSP',
  dscmeta_module_version: '1.1.0.0',
  docs: 'The DSC xCredSSP resource type.
         Automatically generated from version 1.1.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_delegatecomputers: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the array of computers that CredSSP client can delegate to.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_role: {
      type: "Enum['Server', 'Client']",
      desc: 'Specifies the CredSSP role. Server    Client    ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'An enumerated value that describes if the role is expected to be enabled on the machine. Present {default}   Absent    ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
